@@ -2,7 +2,10 @@
         Copyright (C) 1993-2005 Hewlett-Packard Company
 */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #if defined(HAVE_SYS_SOCKET_H)
 # include <sys/socket.h>
 #endif
@@ -269,6 +272,11 @@ struct ring_elt {
 #define EINTR    WSAEINTR
 #define ENOBUFS  WSAENOBUFS
 #define EWOULDBLOCK    WSAEWOULDBLOCK
+#define EAFNOSUPPORT  WSAEAFNOSUPPORT
+/* I don't use a C++ style of comment because it upsets some C
+   compilers, possibly even when it is inside an ifdef WIN32... */
+/* from public\sdk\inc\crt\errno.h */
+#define ENOSPC          28
 
 #ifdef errno
 /* delete the one from stdlib.h  */
@@ -321,10 +329,10 @@ extern void PrintWin32Error(FILE *stream, LPSTR text);
 	      (errno == WSAECONNRESET) ))
 #define SOCKET_EADDRINUSE(return_value) \
 		(((return_value) == SOCKET_ERROR) && \
-	     ((errno == EADDRINUSE) ))
+	     ((errno == WSAEADDRINUSE) ))
 #define SOCKET_EADDRNOTAVAIL(return_value) \
 		(((return_value) == SOCKET_ERROR) && \
-	     ((errno == EADDRNOTAVAIL) ))
+	     ((errno == WSAEADDRNOTAVAIL) ))
 #endif
 
 #ifdef HAVE_SENDFILE
@@ -365,6 +373,7 @@ struct sendfile_ring_elt {
 #define SYSCTL          9
 #define PERFSTAT       10
 #define KSTAT_10       11
+#define OSX            12
 
 #define BADCH ('?')
 
@@ -382,7 +391,7 @@ extern int optopt;		/* */
 
 #endif /* _GETOPT_ */
 
-extern  SOCKET     win_kludge_socket;
+extern  SOCKET     win_kludge_socket, win_kludge_socket2;
 #endif /* WIN32 */
 
 extern  int   local_proc_affinity, remote_proc_affinity;
@@ -451,7 +460,7 @@ extern  void	retrieve_confident_values(float *elapsed_time,
 			  float *local_service_demand,
 			  float *remote_service_demand);
 extern  void    display_confidence();
-extern  void    set_sock_buffer(int sd,
+extern  void    set_sock_buffer(SOCKET sd,
 				enum sock_buffer which,
 				int requested_size,
 				int *effective_sizep);
@@ -468,7 +477,7 @@ extern  double  calc_thruput(double units_received);
 extern  double  calc_thruput_interval(double units_received,double elapsed);
 extern  float   calibrate_local_cpu(float local_cpu_rate);
 extern  float   calibrate_remote_cpu();
-extern  void    bind_to_specific_processor(int processor_affinity);
+extern  void    bind_to_specific_processor(int processor_affinity,int use_cpu_map);
 #ifndef WIN32
 
 /* WIN32 requires that at least one of the file sets to select be
@@ -488,15 +497,22 @@ extern  void    catcher(int, siginfo_t *,void *);
 extern  void    catcher(int);
 #endif /* __hpux */
 extern  struct ring_elt *allocate_buffer_ring();
+extern void access_buffer(char *buffer_ptr,
+			  int length,
+			  int dirty_count,
+			  int clean_count);
+
 #ifdef HAVE_ICSC_EXS
 extern  struct ring_elt *allocate_exs_buffer_ring();
 #endif /* HAVE_ICSC_EXS */
 #ifdef HAVE_SENDFILE
 extern  struct sendfile_ring_elt *alloc_sendfile_buf_ring();
 #endif /* HAVE_SENDFILE */
+#ifdef WANT_DLPI
 extern  int     dl_connect(int fd, unsigned char *rem_addr, int rem_addr_len);
 extern  int     dl_bind(int fd, int sap, int mode, char *dlsap_ptr, int *dlsap_len);
 extern  int     dl_open(char devfile[], int ppa);
+#endif /* WANT_DLPI */
 extern  char    format_cpu_method(int method);
 extern unsigned int convert(char *string);
 
