@@ -94,7 +94,7 @@ double atof(const char *);
  /* Some of the args take optional parameters. Since we are using */
  /* getopt to parse the command line, we will tell getopt that they do */
  /* not take parms, and then look for them ourselves */
-#define GLOBAL_CMD_LINE_ARGS "A:a:b:CcdDf:F:H:hi:I:l:L:n:O:o:P:p:t:T:v:W:w:46"
+#define GLOBAL_CMD_LINE_ARGS "A:a:b:B:CcdDf:F:H:hi:I:k:K:l:L:n:O:o:P:p:t:T:v:W:w:46"
 
 /************************************************************************/
 /*									*/
@@ -137,6 +137,12 @@ int
   print_headers,		/* do/don't display headers */
   verbosity;		/* verbosity level */
 
+/* When specified with -B, this will be displayed at the end of the line
+   for output that does not include the test header.  mostly this is
+   to help identify a specific netperf result when concurrent netperfs
+   are run. raj 2006-02-01 */
+char *result_brand = NULL;
+
 /* cpu variables */
 int
   local_cpu_usage,	/* you guessed it			*/
@@ -169,23 +175,21 @@ int
   remote_send_offset = 0,
   remote_recv_offset = 0;
 
-#ifdef WANT_INTERVALS
+#if defined(WANT_INTERVALS) || defined(WANT_DEMO)
 int
   interval_usecs,
   interval_wate,
   interval_burst;
-#endif /* WANT_INTERVALS */
 
-#ifdef WANT_DEMO
-int demo_mode;               /* are we actually in demo mode? */
+int demo_mode;                    /* are we actually in demo mode? */
 double demo_interval = 1000000.0; /* what is the desired interval to
 				     display interval results. default
 				     is one second in units of
 				     microseconds */
-double demo_units = 0.0;     /* what is our current best guess as to
-				how many work units must be done to be
-				near the desired reporting
-				interval? */ 
+double demo_units = 0.0;          /* what is our current best guess as
+				     to how many work units must be
+				     done to be near the desired
+				     reporting interval? */ 
 
 double units_this_tick;
 #endif
@@ -213,6 +217,9 @@ int     recv_width;
 /* address family */
 int	af = AF_INET;
 
+/* did someone request processor affinity? */
+int cpu_binding_requested = 0;
+
 char netserver_usage[] = "\n\
 Usage: netserver [options] \n\
 \n\
@@ -236,6 +243,7 @@ Usage: netperf [global options] -- [test options] \n\
 Global options:\n\
     -a send,recv      Set the local send,recv buffer alignment\n\
     -A send,recv      Set the remote send,recv buffer alignment\n\
+    -B brandstr       Specify a string to be emitted with brief output\n\
     -c [cpu_rate]     Report local CPU usage\n\
     -C [cpu_rate]     Report remote CPU usage\n\
     -d                Increase debugging output\n\
@@ -629,10 +637,12 @@ scan_cmd_line(int argc, char *argv[])
       break_args(optarg,arg1,arg2);
       if (arg1[0]) {
 	local_proc_affinity = convert(arg1);
-	bind_to_specific_processor(local_proc_affinity);
+	bind_to_specific_processor(local_proc_affinity,0);
       }
-      if (arg2[0])
+      if (arg2[0]) {
 	remote_proc_affinity = convert(arg2);
+      }
+      cpu_binding_requested = 1;
       break;
     case 'W':
       /* set the "width" of the user space data buffer ring. This will */
@@ -695,8 +705,8 @@ scan_cmd_line(int argc, char *argv[])
       /* second, and that the packet rate is */
       /* expressed in packets per millisecond. */
 #ifdef WANT_INTERVALS
-      interval_wate  = convert(optarg);
-      interval_usecs = interval_wate * 1000;
+      interval_usecs = convert_timespec(optarg);
+      interval_wate  = interval_usecs / 1000;
 #else
       fprintf(where,
 	      "Packet rate control is not compiled in.\n");
@@ -712,6 +722,16 @@ scan_cmd_line(int argc, char *argv[])
 	      "Packet burst size is not compiled in. \n");
 #endif /* WANT_INTERVALS */
       break;
+    case 'B':
+      result_brand = malloc(strlen(optarg)+1);
+      if (NULL != result_brand) {
+	strcpy(result_brand,optarg);
+      }
+      else {
+	fprintf(where,
+		"Unable to malloc space for result brand\n");
+      }
+      break;
     case '4':
       address_family = AF_INET;
       local_address_family = AF_INET;
